Class: Aws::DeviceFarm::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DeviceFarm::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-devicefarm/client.rb,
sig/client.rbs
Overview
An API client for DeviceFarm. To construct a client, you need to configure a :region and :credentials.
client = Aws::DeviceFarm::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateDevicePoolResponseSuccess, _CreateInstanceProfileResponseSuccess, _CreateNetworkProfileResponseSuccess, _CreateProjectResponseSuccess, _CreateRemoteAccessSessionResponseSuccess, _CreateTestGridProjectResponseSuccess, _CreateTestGridUrlResponseSuccess, _CreateUploadResponseSuccess, _CreateVPCEConfigurationResponseSuccess, _DeleteDevicePoolResponseSuccess, _DeleteInstanceProfileResponseSuccess, _DeleteNetworkProfileResponseSuccess, _DeleteProjectResponseSuccess, _DeleteRemoteAccessSessionResponseSuccess, _DeleteRunResponseSuccess, _DeleteTestGridProjectResponseSuccess, _DeleteUploadResponseSuccess, _DeleteVPCEConfigurationResponseSuccess, _GetAccountSettingsResponseSuccess, _GetDeviceInstanceResponseSuccess, _GetDevicePoolCompatibilityResponseSuccess, _GetDevicePoolResponseSuccess, _GetDeviceResponseSuccess, _GetInstanceProfileResponseSuccess, _GetJobResponseSuccess, _GetNetworkProfileResponseSuccess, _GetOfferingStatusResponseSuccess, _GetProjectResponseSuccess, _GetRemoteAccessSessionResponseSuccess, _GetRunResponseSuccess, _GetSuiteResponseSuccess, _GetTestGridProjectResponseSuccess, _GetTestGridSessionResponseSuccess, _GetTestResponseSuccess, _GetUploadResponseSuccess, _GetVPCEConfigurationResponseSuccess, _InstallToRemoteAccessSessionResponseSuccess, _ListArtifactsResponseSuccess, _ListDeviceInstancesResponseSuccess, _ListDevicePoolsResponseSuccess, _ListDevicesResponseSuccess, _ListInstanceProfilesResponseSuccess, _ListJobsResponseSuccess, _ListNetworkProfilesResponseSuccess, _ListOfferingPromotionsResponseSuccess, _ListOfferingTransactionsResponseSuccess, _ListOfferingsResponseSuccess, _ListProjectsResponseSuccess, _ListRemoteAccessSessionsResponseSuccess, _ListRunsResponseSuccess, _ListSamplesResponseSuccess, _ListSuitesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTestGridProjectsResponseSuccess, _ListTestGridSessionActionsResponseSuccess, _ListTestGridSessionArtifactsResponseSuccess, _ListTestGridSessionsResponseSuccess, _ListTestsResponseSuccess, _ListUniqueProblemsResponseSuccess, _ListUploadsResponseSuccess, _ListVPCEConfigurationsResponseSuccess, _PurchaseOfferingResponseSuccess, _RenewOfferingResponseSuccess, _ScheduleRunResponseSuccess, _StopJobResponseSuccess, _StopRemoteAccessSessionResponseSuccess, _StopRunResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDeviceInstanceResponseSuccess, _UpdateDevicePoolResponseSuccess, _UpdateInstanceProfileResponseSuccess, _UpdateNetworkProfileResponseSuccess, _UpdateProjectResponseSuccess, _UpdateTestGridProjectResponseSuccess, _UpdateUploadResponseSuccess, _UpdateVPCEConfigurationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_device_pool(params = {}) ⇒ Types::CreateDevicePoolResult
Creates a device pool.
-
#create_instance_profile(params = {}) ⇒ Types::CreateInstanceProfileResult
Creates a profile that can be applied to one or more private fleet device instances.
-
#create_network_profile(params = {}) ⇒ Types::CreateNetworkProfileResult
Creates a network profile.
-
#create_project(params = {}) ⇒ Types::CreateProjectResult
Creates a project.
-
#create_remote_access_session(params = {}) ⇒ Types::CreateRemoteAccessSessionResult
Specifies and starts a remote access session.
-
#create_test_grid_project(params = {}) ⇒ Types::CreateTestGridProjectResult
Creates a Selenium testing project.
-
#create_test_grid_url(params = {}) ⇒ Types::CreateTestGridUrlResult
Creates a signed, short-term URL that can be passed to a Selenium
RemoteWebDriverconstructor. -
#create_upload(params = {}) ⇒ Types::CreateUploadResult
Uploads an app or test scripts.
-
#create_vpce_configuration(params = {}) ⇒ Types::CreateVPCEConfigurationResult
Creates a configuration record in Device Farm for your Amazon Virtual Private Cloud (VPC) endpoint.
-
#delete_device_pool(params = {}) ⇒ Struct
Deletes a device pool given the pool ARN.
-
#delete_instance_profile(params = {}) ⇒ Struct
Deletes a profile that can be applied to one or more private device instances.
-
#delete_network_profile(params = {}) ⇒ Struct
Deletes a network profile.
-
#delete_project(params = {}) ⇒ Struct
Deletes an AWS Device Farm project, given the project ARN.
-
#delete_remote_access_session(params = {}) ⇒ Struct
Deletes a completed remote access session and its results.
-
#delete_run(params = {}) ⇒ Struct
Deletes the run, given the run ARN.
-
#delete_test_grid_project(params = {}) ⇒ Struct
Deletes a Selenium testing project and all content generated under it.
-
#delete_upload(params = {}) ⇒ Struct
Deletes an upload given the upload ARN.
-
#delete_vpce_configuration(params = {}) ⇒ Struct
Deletes a configuration for your Amazon Virtual Private Cloud (VPC) endpoint.
-
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResult
Returns the number of unmetered iOS or unmetered Android devices that have been purchased by the account.
-
#get_device(params = {}) ⇒ Types::GetDeviceResult
Gets information about a unique device type.
-
#get_device_instance(params = {}) ⇒ Types::GetDeviceInstanceResult
Returns information about a device instance that belongs to a private device fleet.
-
#get_device_pool(params = {}) ⇒ Types::GetDevicePoolResult
Gets information about a device pool.
-
#get_device_pool_compatibility(params = {}) ⇒ Types::GetDevicePoolCompatibilityResult
Gets information about compatibility with a device pool.
-
#get_instance_profile(params = {}) ⇒ Types::GetInstanceProfileResult
Returns information about the specified instance profile.
-
#get_job(params = {}) ⇒ Types::GetJobResult
Gets information about a job.
-
#get_network_profile(params = {}) ⇒ Types::GetNetworkProfileResult
Returns information about a network profile.
-
#get_offering_status(params = {}) ⇒ Types::GetOfferingStatusResult
Gets the current status and future status of all offerings purchased by an AWS account.
-
#get_project(params = {}) ⇒ Types::GetProjectResult
Gets information about a project.
-
#get_remote_access_session(params = {}) ⇒ Types::GetRemoteAccessSessionResult
Returns a link to a currently running remote access session.
-
#get_run(params = {}) ⇒ Types::GetRunResult
Gets information about a run.
-
#get_suite(params = {}) ⇒ Types::GetSuiteResult
Gets information about a suite.
-
#get_test(params = {}) ⇒ Types::GetTestResult
Gets information about a test.
-
#get_test_grid_project(params = {}) ⇒ Types::GetTestGridProjectResult
Retrieves information about a Selenium testing project.
-
#get_test_grid_session(params = {}) ⇒ Types::GetTestGridSessionResult
A session is an instance of a browser created through a
RemoteWebDriverwith the URL from CreateTestGridUrlResult$url. -
#get_upload(params = {}) ⇒ Types::GetUploadResult
Gets information about an upload.
-
#get_vpce_configuration(params = {}) ⇒ Types::GetVPCEConfigurationResult
Returns information about the configuration settings for your Amazon Virtual Private Cloud (VPC) endpoint.
-
#install_to_remote_access_session(params = {}) ⇒ Types::InstallToRemoteAccessSessionResult
Installs an application to the device in a remote access session.
-
#list_artifacts(params = {}) ⇒ Types::ListArtifactsResult
Gets information about artifacts.
-
#list_device_instances(params = {}) ⇒ Types::ListDeviceInstancesResult
Returns information about the private device instances associated with one or more AWS accounts.
-
#list_device_pools(params = {}) ⇒ Types::ListDevicePoolsResult
Gets information about device pools.
-
#list_devices(params = {}) ⇒ Types::ListDevicesResult
Gets information about unique device types.
-
#list_instance_profiles(params = {}) ⇒ Types::ListInstanceProfilesResult
Returns information about all the instance profiles in an AWS account.
-
#list_jobs(params = {}) ⇒ Types::ListJobsResult
Gets information about jobs for a given test run.
-
#list_network_profiles(params = {}) ⇒ Types::ListNetworkProfilesResult
Returns the list of available network profiles.
-
#list_offering_promotions(params = {}) ⇒ Types::ListOfferingPromotionsResult
Returns a list of offering promotions.
-
#list_offering_transactions(params = {}) ⇒ Types::ListOfferingTransactionsResult
Returns a list of all historical purchases, renewals, and system renewal transactions for an AWS account.
-
#list_offerings(params = {}) ⇒ Types::ListOfferingsResult
Returns a list of products or offerings that the user can manage through the API.
-
#list_projects(params = {}) ⇒ Types::ListProjectsResult
Gets information about projects.
-
#list_remote_access_sessions(params = {}) ⇒ Types::ListRemoteAccessSessionsResult
Returns a list of all currently running remote access sessions.
-
#list_runs(params = {}) ⇒ Types::ListRunsResult
Gets information about runs, given an AWS Device Farm project ARN.
-
#list_samples(params = {}) ⇒ Types::ListSamplesResult
Gets information about samples, given an AWS Device Farm job ARN.
-
#list_suites(params = {}) ⇒ Types::ListSuitesResult
Gets information about test suites for a given job.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the tags for an AWS Device Farm resource.
-
#list_test_grid_projects(params = {}) ⇒ Types::ListTestGridProjectsResult
Gets a list of all Selenium testing projects in your account.
-
#list_test_grid_session_actions(params = {}) ⇒ Types::ListTestGridSessionActionsResult
Returns a list of the actions taken in a TestGridSession.
-
#list_test_grid_session_artifacts(params = {}) ⇒ Types::ListTestGridSessionArtifactsResult
Retrieves a list of artifacts created during the session.
-
#list_test_grid_sessions(params = {}) ⇒ Types::ListTestGridSessionsResult
Retrieves a list of sessions for a TestGridProject.
-
#list_tests(params = {}) ⇒ Types::ListTestsResult
Gets information about tests in a given test suite.
-
#list_unique_problems(params = {}) ⇒ Types::ListUniqueProblemsResult
Gets information about unique problems, such as exceptions or crashes.
-
#list_uploads(params = {}) ⇒ Types::ListUploadsResult
Gets information about uploads, given an AWS Device Farm project ARN.
-
#list_vpce_configurations(params = {}) ⇒ Types::ListVPCEConfigurationsResult
Returns information about all Amazon Virtual Private Cloud (VPC) endpoint configurations in the AWS account.
-
#purchase_offering(params = {}) ⇒ Types::PurchaseOfferingResult
Immediately purchases offerings for an AWS account.
-
#renew_offering(params = {}) ⇒ Types::RenewOfferingResult
Explicitly sets the quantity of devices to renew for an offering, starting from the
effectiveDateof the next period. -
#schedule_run(params = {}) ⇒ Types::ScheduleRunResult
Schedules a run.
-
#stop_job(params = {}) ⇒ Types::StopJobResult
Initiates a stop request for the current job.
-
#stop_remote_access_session(params = {}) ⇒ Types::StopRemoteAccessSessionResult
Ends a specified remote access session.
-
#stop_run(params = {}) ⇒ Types::StopRunResult
Initiates a stop request for the current test run.
-
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to a resource with the specified
resourceArn. -
#untag_resource(params = {}) ⇒ Struct
Deletes the specified tags from a resource.
-
#update_device_instance(params = {}) ⇒ Types::UpdateDeviceInstanceResult
Updates information about a private device instance.
-
#update_device_pool(params = {}) ⇒ Types::UpdateDevicePoolResult
Modifies the name, description, and rules in a device pool given the attributes and the pool ARN.
-
#update_instance_profile(params = {}) ⇒ Types::UpdateInstanceProfileResult
Updates information about an existing private device instance profile.
-
#update_network_profile(params = {}) ⇒ Types::UpdateNetworkProfileResult
Updates the network profile.
-
#update_project(params = {}) ⇒ Types::UpdateProjectResult
Modifies the specified project name, given the project ARN and a new name.
-
#update_test_grid_project(params = {}) ⇒ Types::UpdateTestGridProjectResult
Change details of a project.
-
#update_upload(params = {}) ⇒ Types::UpdateUploadResult
Updates an uploaded test spec.
-
#update_vpce_configuration(params = {}) ⇒ Types::UpdateVPCEConfigurationResult
Updates information about an Amazon Virtual Private Cloud (VPC) endpoint configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-devicefarm/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6265 6266 6267 |
# File 'lib/aws-sdk-devicefarm/client.rb', line 6265 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6268 6269 6270 |
# File 'lib/aws-sdk-devicefarm/client.rb', line 6268 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6238 6239 6240 6241 6242 6243 6244 6245 6246 6247 6248 6249 6250 6251 6252 6253 6254 |
# File 'lib/aws-sdk-devicefarm/client.rb', line 6238 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DeviceFarm') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-devicefarm' context[:gem_version] = '1.108.0' Seahorse::Client::Request.new(handlers, context) end |
#create_device_pool(params = {}) ⇒ Types::CreateDevicePoolResult
Creates a device pool.
87 |
# File 'sig/client.rbs', line 87
def create_device_pool: (
|
#create_instance_profile(params = {}) ⇒ Types::CreateInstanceProfileResult
Creates a profile that can be applied to one or more private fleet device instances.
107 |
# File 'sig/client.rbs', line 107
def create_instance_profile: (
|
#create_network_profile(params = {}) ⇒ Types::CreateNetworkProfileResult
Creates a network profile.
121 |
# File 'sig/client.rbs', line 121
def create_network_profile: (
|
#create_project(params = {}) ⇒ Types::CreateProjectResult
Creates a project.
142 |
# File 'sig/client.rbs', line 142
def create_project: (
|
#create_remote_access_session(params = {}) ⇒ Types::CreateRemoteAccessSessionResult
Specifies and starts a remote access session.
165 |
# File 'sig/client.rbs', line 165
def create_remote_access_session: (
|
#create_test_grid_project(params = {}) ⇒ Types::CreateTestGridProjectResult
Creates a Selenium testing project. Projects are used to track TestGridSession instances.
190 |
# File 'sig/client.rbs', line 190
def create_test_grid_project: (
|
#create_test_grid_url(params = {}) ⇒ Types::CreateTestGridUrlResult
Creates a signed, short-term URL that can be passed to a Selenium
RemoteWebDriver constructor.
207 |
# File 'sig/client.rbs', line 207
def create_test_grid_url: (
|
#create_upload(params = {}) ⇒ Types::CreateUploadResult
Uploads an app or test scripts.
218 |
# File 'sig/client.rbs', line 218
def create_upload: (
|
#create_vpce_configuration(params = {}) ⇒ Types::CreateVPCEConfigurationResult
Creates a configuration record in Device Farm for your Amazon Virtual Private Cloud (VPC) endpoint.
231 |
# File 'sig/client.rbs', line 231
def create_vpce_configuration: (
|
#delete_device_pool(params = {}) ⇒ Struct
Deletes a device pool given the pool ARN. Does not allow deletion of curated pools owned by the system.
243 |
# File 'sig/client.rbs', line 243
def delete_device_pool: (
|
#delete_instance_profile(params = {}) ⇒ Struct
Deletes a profile that can be applied to one or more private device instances.
252 |
# File 'sig/client.rbs', line 252
def delete_instance_profile: (
|
#delete_network_profile(params = {}) ⇒ Struct
Deletes a network profile.
261 |
# File 'sig/client.rbs', line 261
def delete_network_profile: (
|
#delete_project(params = {}) ⇒ Struct
Deletes an AWS Device Farm project, given the project ARN. You cannot delete a project if it has an active run or session.
You cannot undo this operation.
270 |
# File 'sig/client.rbs', line 270
def delete_project: (
|
#delete_remote_access_session(params = {}) ⇒ Struct
Deletes a completed remote access session and its results. You cannot delete a remote access session if it is still active.
You cannot undo this operation.
279 |
# File 'sig/client.rbs', line 279
def delete_remote_access_session: (
|
#delete_run(params = {}) ⇒ Struct
Deletes the run, given the run ARN. You cannot delete a run if it is still active.
You cannot undo this operation.
288 |
# File 'sig/client.rbs', line 288
def delete_run: (
|
#delete_test_grid_project(params = {}) ⇒ Struct
Deletes a Selenium testing project and all content generated under it. You cannot delete a project if it has active sessions.
You cannot undo this operation.
297 |
# File 'sig/client.rbs', line 297
def delete_test_grid_project: (
|
#delete_upload(params = {}) ⇒ Struct
Deletes an upload given the upload ARN.
306 |
# File 'sig/client.rbs', line 306
def delete_upload: (
|
#delete_vpce_configuration(params = {}) ⇒ Struct
Deletes a configuration for your Amazon Virtual Private Cloud (VPC) endpoint.
315 |
# File 'sig/client.rbs', line 315
def delete_vpce_configuration: (
|
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResult
Returns the number of unmetered iOS or unmetered Android devices that have been purchased by the account.
325 |
# File 'sig/client.rbs', line 325
def get_account_settings: (
|
#get_device(params = {}) ⇒ Types::GetDeviceResult
Gets information about a unique device type.
334 |
# File 'sig/client.rbs', line 334
def get_device: (
|
#get_device_instance(params = {}) ⇒ Types::GetDeviceInstanceResult
Returns information about a device instance that belongs to a private device fleet.
344 |
# File 'sig/client.rbs', line 344
def get_device_instance: (
|
#get_device_pool(params = {}) ⇒ Types::GetDevicePoolResult
Gets information about a device pool.
354 |
# File 'sig/client.rbs', line 354
def get_device_pool: (
|
#get_device_pool_compatibility(params = {}) ⇒ Types::GetDevicePoolCompatibilityResult
Gets information about compatibility with a device pool.
365 |
# File 'sig/client.rbs', line 365
def get_device_pool_compatibility: (
|
#get_instance_profile(params = {}) ⇒ Types::GetInstanceProfileResult
Returns information about the specified instance profile.
386 |
# File 'sig/client.rbs', line 386
def get_instance_profile: (
|
#get_job(params = {}) ⇒ Types::GetJobResult
Gets information about a job.
396 |
# File 'sig/client.rbs', line 396
def get_job: (
|
#get_network_profile(params = {}) ⇒ Types::GetNetworkProfileResult
Returns information about a network profile.
406 |
# File 'sig/client.rbs', line 406
def get_network_profile: (
|
#get_offering_status(params = {}) ⇒ Types::GetOfferingStatusResult
Gets the current status and future status of all offerings purchased
by an AWS account. The response indicates how many offerings are
currently available and the offerings that will be available in the
next period. The API returns a NotEligible error if the user is not
permitted to invoke the operation. If you must be able to invoke this
operation, contact
aws-devicefarm-support@amazon.com.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
418 |
# File 'sig/client.rbs', line 418
def get_offering_status: (
|
#get_project(params = {}) ⇒ Types::GetProjectResult
Gets information about a project.
428 |
# File 'sig/client.rbs', line 428
def get_project: (
|
#get_remote_access_session(params = {}) ⇒ Types::GetRemoteAccessSessionResult
Returns a link to a currently running remote access session.
438 |
# File 'sig/client.rbs', line 438
def get_remote_access_session: (
|
#get_run(params = {}) ⇒ Types::GetRunResult
Gets information about a run.
448 |
# File 'sig/client.rbs', line 448
def get_run: (
|
#get_suite(params = {}) ⇒ Types::GetSuiteResult
Gets information about a suite.
458 |
# File 'sig/client.rbs', line 458
def get_suite: (
|
#get_test(params = {}) ⇒ Types::GetTestResult
Gets information about a test.
468 |
# File 'sig/client.rbs', line 468
def get_test: (
|
#get_test_grid_project(params = {}) ⇒ Types::GetTestGridProjectResult
Retrieves information about a Selenium testing project.
478 |
# File 'sig/client.rbs', line 478
def get_test_grid_project: (
|
#get_test_grid_session(params = {}) ⇒ Types::GetTestGridSessionResult
A session is an instance of a browser created through a
RemoteWebDriver with the URL from CreateTestGridUrlResult$url. You
can use the following to look up sessions:
-
The session ARN (GetTestGridSessionRequest$sessionArn).
-
The project ARN and a session ID (GetTestGridSessionRequest$projectArn and GetTestGridSessionRequest$sessionId).
488 |
# File 'sig/client.rbs', line 488
def get_test_grid_session: (
|
#get_upload(params = {}) ⇒ Types::GetUploadResult
Gets information about an upload.
500 |
# File 'sig/client.rbs', line 500
def get_upload: (
|
#get_vpce_configuration(params = {}) ⇒ Types::GetVPCEConfigurationResult
Returns information about the configuration settings for your Amazon Virtual Private Cloud (VPC) endpoint.
510 |
# File 'sig/client.rbs', line 510
def get_vpce_configuration: (
|
#install_to_remote_access_session(params = {}) ⇒ Types::InstallToRemoteAccessSessionResult
Installs an application to the device in a remote access session. For Android applications, the file must be in .apk format. For iOS applications, the file must be in .ipa format.
520 |
# File 'sig/client.rbs', line 520
def install_to_remote_access_session: (
|
#list_artifacts(params = {}) ⇒ Types::ListArtifactsResult
Gets information about artifacts.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
532 |
# File 'sig/client.rbs', line 532
def list_artifacts: (
|
#list_device_instances(params = {}) ⇒ Types::ListDeviceInstancesResult
Returns information about the private device instances associated with one or more AWS accounts.
545 |
# File 'sig/client.rbs', line 545
def list_device_instances: (
|
#list_device_pools(params = {}) ⇒ Types::ListDevicePoolsResult
Gets information about device pools.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
557 |
# File 'sig/client.rbs', line 557
def list_device_pools: (
|
#list_devices(params = {}) ⇒ Types::ListDevicesResult
Gets information about unique device types.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
570 |
# File 'sig/client.rbs', line 570
def list_devices: (
|
#list_instance_profiles(params = {}) ⇒ Types::ListInstanceProfilesResult
Returns information about all the instance profiles in an AWS account.
589 |
# File 'sig/client.rbs', line 589
def list_instance_profiles: (
|
#list_jobs(params = {}) ⇒ Types::ListJobsResult
Gets information about jobs for a given test run.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
601 |
# File 'sig/client.rbs', line 601
def list_jobs: (
|
#list_network_profiles(params = {}) ⇒ Types::ListNetworkProfilesResult
Returns the list of available network profiles.
613 |
# File 'sig/client.rbs', line 613
def list_network_profiles: (
|
#list_offering_promotions(params = {}) ⇒ Types::ListOfferingPromotionsResult
Returns a list of offering promotions. Each offering promotion record
contains the ID and description of the promotion. The API returns a
NotEligible error if the caller is not permitted to invoke the
operation. Contact
aws-devicefarm-support@amazon.com
if you must be able to invoke this operation.
626 |
# File 'sig/client.rbs', line 626
def list_offering_promotions: (
|
#list_offering_transactions(params = {}) ⇒ Types::ListOfferingTransactionsResult
Returns a list of all historical purchases, renewals, and system
renewal transactions for an AWS account. The list is paginated and
ordered by a descending timestamp (most recent transactions are
first). The API returns a NotEligible error if the user is not
permitted to invoke the operation. If you must be able to invoke this
operation, contact
aws-devicefarm-support@amazon.com.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
637 |
# File 'sig/client.rbs', line 637
def list_offering_transactions: (
|
#list_offerings(params = {}) ⇒ Types::ListOfferingsResult
Returns a list of products or offerings that the user can manage
through the API. Each offering record indicates the recurring price
per unit and the frequency for that offering. The API returns a
NotEligible error if the user is not permitted to invoke the
operation. If you must be able to invoke this operation, contact
aws-devicefarm-support@amazon.com.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
648 |
# File 'sig/client.rbs', line 648
def list_offerings: (
|
#list_projects(params = {}) ⇒ Types::ListProjectsResult
Gets information about projects.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
659 |
# File 'sig/client.rbs', line 659
def list_projects: (
|
#list_remote_access_sessions(params = {}) ⇒ Types::ListRemoteAccessSessionsResult
Returns a list of all currently running remote access sessions.
671 |
# File 'sig/client.rbs', line 671
def list_remote_access_sessions: (
|
#list_runs(params = {}) ⇒ Types::ListRunsResult
Gets information about runs, given an AWS Device Farm project ARN.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
683 |
# File 'sig/client.rbs', line 683
def list_runs: (
|
#list_samples(params = {}) ⇒ Types::ListSamplesResult
Gets information about samples, given an AWS Device Farm job ARN.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
695 |
# File 'sig/client.rbs', line 695
def list_samples: (
|
#list_suites(params = {}) ⇒ Types::ListSuitesResult
Gets information about test suites for a given job.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
707 |
# File 'sig/client.rbs', line 707
def list_suites: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the tags for an AWS Device Farm resource.
718 |
# File 'sig/client.rbs', line 718
def list_tags_for_resource: (
|
#list_test_grid_projects(params = {}) ⇒ Types::ListTestGridProjectsResult
Gets a list of all Selenium testing projects in your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
729 |
# File 'sig/client.rbs', line 729
def list_test_grid_projects: (
|
#list_test_grid_session_actions(params = {}) ⇒ Types::ListTestGridSessionActionsResult
Returns a list of the actions taken in a TestGridSession.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
741 |
# File 'sig/client.rbs', line 741
def list_test_grid_session_actions: (
|
#list_test_grid_session_artifacts(params = {}) ⇒ Types::ListTestGridSessionArtifactsResult
Retrieves a list of artifacts created during the session.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
754 |
# File 'sig/client.rbs', line 754
def list_test_grid_session_artifacts: (
|
#list_test_grid_sessions(params = {}) ⇒ Types::ListTestGridSessionsResult
Retrieves a list of sessions for a TestGridProject.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
768 |
# File 'sig/client.rbs', line 768
def list_test_grid_sessions: (
|
#list_tests(params = {}) ⇒ Types::ListTestsResult
Gets information about tests in a given test suite.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
786 |
# File 'sig/client.rbs', line 786
def list_tests: (
|
#list_unique_problems(params = {}) ⇒ Types::ListUniqueProblemsResult
Gets information about unique problems, such as exceptions or crashes.
Unique problems are defined as a single instance of an error across a
run, job, or suite. For example, if a call in your application
consistently raises an exception (OutOfBoundsException in MyActivity.java:386), ListUniqueProblems returns a single entry
instead of many individual entries for that exception.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
798 |
# File 'sig/client.rbs', line 798
def list_unique_problems: (
|
#list_uploads(params = {}) ⇒ Types::ListUploadsResult
Gets information about uploads, given an AWS Device Farm project ARN.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
810 |
# File 'sig/client.rbs', line 810
def list_uploads: (
|
#list_vpce_configurations(params = {}) ⇒ Types::ListVPCEConfigurationsResult
Returns information about all Amazon Virtual Private Cloud (VPC) endpoint configurations in the AWS account.
823 |
# File 'sig/client.rbs', line 823
def list_vpce_configurations: (
|
#purchase_offering(params = {}) ⇒ Types::PurchaseOfferingResult
Immediately purchases offerings for an AWS account. Offerings renew
with the latest total purchased quantity for an offering, unless the
renewal was overridden. The API returns a NotEligible error if the
user is not permitted to invoke the operation. If you must be able to
invoke this operation, contact
aws-devicefarm-support@amazon.com.
834 |
# File 'sig/client.rbs', line 834
def purchase_offering: (
|
#renew_offering(params = {}) ⇒ Types::RenewOfferingResult
Explicitly sets the quantity of devices to renew for an offering,
starting from the effectiveDate of the next period. The API returns
a NotEligible error if the user is not permitted to invoke the
operation. If you must be able to invoke this operation, contact
aws-devicefarm-support@amazon.com.
846 |
# File 'sig/client.rbs', line 846
def renew_offering: (
|
#schedule_run(params = {}) ⇒ Types::ScheduleRunResult
Schedules a run.
857 |
# File 'sig/client.rbs', line 857
def schedule_run: (
|
#stop_job(params = {}) ⇒ Types::StopJobResult
Initiates a stop request for the current job. AWS Device Farm immediately stops the job on the device where tests have not started. You are not billed for this device. On the device where tests have started, setup suite and teardown suite tests run to completion on the device. You are billed for setup, teardown, and any tests that were in progress or already completed.
895 |
# File 'sig/client.rbs', line 895
def stop_job: (
|
#stop_remote_access_session(params = {}) ⇒ Types::StopRemoteAccessSessionResult
Ends a specified remote access session.
905 |
# File 'sig/client.rbs', line 905
def stop_remote_access_session: (
|
#stop_run(params = {}) ⇒ Types::StopRunResult
Initiates a stop request for the current test run. AWS Device Farm immediately stops the run on devices where tests have not started. You are not billed for these devices. On devices where tests have started executing, setup suite and teardown suite tests run to completion on those devices. You are billed for setup, teardown, and any tests that were in progress or already completed.
915 |
# File 'sig/client.rbs', line 915
def stop_run: (
|
#tag_resource(params = {}) ⇒ Struct
Associates the specified tags to a resource with the specified
resourceArn. If existing tags on a resource are not specified in the
request parameters, they are not changed. When a resource is deleted,
the tags associated with that resource are also deleted.
924 |
# File 'sig/client.rbs', line 924
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Deletes the specified tags from a resource.
939 |
# File 'sig/client.rbs', line 939
def untag_resource: (
|
#update_device_instance(params = {}) ⇒ Types::UpdateDeviceInstanceResult
Updates information about a private device instance.
950 |
# File 'sig/client.rbs', line 950
def update_device_instance: (
|
#update_device_pool(params = {}) ⇒ Types::UpdateDevicePoolResult
Modifies the name, description, and rules in a device pool given the attributes and the pool ARN. Rule updates are all-or-nothing, meaning they can only be updated as a whole (or not at all).
962 |
# File 'sig/client.rbs', line 962
def update_device_pool: (
|
#update_instance_profile(params = {}) ⇒ Types::UpdateInstanceProfileResult
Updates information about an existing private device instance profile.
983 |
# File 'sig/client.rbs', line 983
def update_instance_profile: (
|
#update_network_profile(params = {}) ⇒ Types::UpdateNetworkProfileResult
Updates the network profile.
998 |
# File 'sig/client.rbs', line 998
def update_network_profile: (
|
#update_project(params = {}) ⇒ Types::UpdateProjectResult
Modifies the specified project name, given the project ARN and a new name.
1019 |
# File 'sig/client.rbs', line 1019
def update_project: (
|
#update_test_grid_project(params = {}) ⇒ Types::UpdateTestGridProjectResult
Change details of a project.
1043 |
# File 'sig/client.rbs', line 1043
def update_test_grid_project: (
|
#update_upload(params = {}) ⇒ Types::UpdateUploadResult
Updates an uploaded test spec.
1060 |
# File 'sig/client.rbs', line 1060
def update_upload: (
|
#update_vpce_configuration(params = {}) ⇒ Types::UpdateVPCEConfigurationResult
Updates information about an Amazon Virtual Private Cloud (VPC) endpoint configuration.
1073 |
# File 'sig/client.rbs', line 1073
def update_vpce_configuration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
6258 6259 6260 |
# File 'lib/aws-sdk-devicefarm/client.rb', line 6258 def waiter_names [] end |