Class: Aws::DeviceFarm::Types::CreateRemoteAccessSessionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Configuration settings for a remote access session, including billing method.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auxiliary_appsArray<String>

A list of upload ARNs for app packages to be installed onto your device. (Maximum 3)

Returns:

  • (Array<String>)


545
546
547
548
549
550
551
552
553
# File 'lib/aws-sdk-devicefarm/types.rb', line 545

class CreateRemoteAccessSessionConfiguration < Struct.new(
  :auxiliary_apps,
  :billing_method,
  :vpce_configuration_arns,
  :device_proxy,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#billing_methodString

The billing method for the remote access session.

Returns:

  • (String)


545
546
547
548
549
550
551
552
553
# File 'lib/aws-sdk-devicefarm/types.rb', line 545

class CreateRemoteAccessSessionConfiguration < Struct.new(
  :auxiliary_apps,
  :billing_method,
  :vpce_configuration_arns,
  :device_proxy,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#device_proxyTypes::DeviceProxy

The device proxy to be configured on the device for the remote access session.

Returns:



545
546
547
548
549
550
551
552
553
# File 'lib/aws-sdk-devicefarm/types.rb', line 545

class CreateRemoteAccessSessionConfiguration < Struct.new(
  :auxiliary_apps,
  :billing_method,
  :vpce_configuration_arns,
  :device_proxy,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,String>

The name-value string pairs that specify additional settings for the remote access session.

  • appium:version: The major version of the Appium server to use for the session (for example, 2 or 3). The service may reject the selected version if it is not available for the selected device.

^

Returns:

  • (Hash<String,String>)


545
546
547
548
549
550
551
552
553
# File 'lib/aws-sdk-devicefarm/types.rb', line 545

class CreateRemoteAccessSessionConfiguration < Struct.new(
  :auxiliary_apps,
  :billing_method,
  :vpce_configuration_arns,
  :device_proxy,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#vpce_configuration_arnsArray<String>

An array of ARNs included in the VPC endpoint configuration.

Returns:

  • (Array<String>)


545
546
547
548
549
550
551
552
553
# File 'lib/aws-sdk-devicefarm/types.rb', line 545

class CreateRemoteAccessSessionConfiguration < Struct.new(
  :auxiliary_apps,
  :billing_method,
  :vpce_configuration_arns,
  :device_proxy,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end