Class: Aws::DeviceFarm::Types::CreateUploadRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::CreateUploadRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents a request to the create upload operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_type ⇒ String
The upload’s content type (for example,
application/octet-stream). -
#name ⇒ String
The upload’s file name.
-
#project_arn ⇒ String
The ARN of the project for the upload.
-
#type ⇒ String
The upload’s upload type.
Instance Attribute Details
#content_type ⇒ String
The upload’s content type (for example, application/octet-stream).
806 807 808 809 810 811 812 813 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 806 class CreateUploadRequest < Struct.new( :project_arn, :name, :type, :content_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The upload’s file name. The name should not contain any forward slashes (/). If you are uploading an iOS app, the file name must end with the .ipa extension. If you are uploading an Android app, the file name must end with the .apk extension. For all others, the file name must end with the .zip file extension.
806 807 808 809 810 811 812 813 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 806 class CreateUploadRequest < Struct.new( :project_arn, :name, :type, :content_type) SENSITIVE = [] include Aws::Structure end |
#project_arn ⇒ String
The ARN of the project for the upload.
806 807 808 809 810 811 812 813 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 806 class CreateUploadRequest < Struct.new( :project_arn, :name, :type, :content_type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The upload’s upload type.
Must be one of the following values:
-
ANDROID_APP
-
IOS_APP
-
WEB_APP
-
EXTERNAL_DATA
-
APPIUM_JAVA_JUNIT_TEST_PACKAGE
-
APPIUM_JAVA_TESTNG_TEST_PACKAGE
-
APPIUM_PYTHON_TEST_PACKAGE
-
APPIUM_NODE_TEST_PACKAGE
-
APPIUM_RUBY_TEST_PACKAGE
-
APPIUM_WEB_JAVA_JUNIT_TEST_PACKAGE
-
APPIUM_WEB_JAVA_TESTNG_TEST_PACKAGE
-
APPIUM_WEB_PYTHON_TEST_PACKAGE
-
APPIUM_WEB_NODE_TEST_PACKAGE
-
APPIUM_WEB_RUBY_TEST_PACKAGE
-
INSTRUMENTATION_TEST_PACKAGE
-
XCTEST_TEST_PACKAGE
-
XCTEST_UI_TEST_PACKAGE
-
APPIUM_JAVA_JUNIT_TEST_SPEC
-
APPIUM_JAVA_TESTNG_TEST_SPEC
-
APPIUM_PYTHON_TEST_SPEC
-
APPIUM_NODE_TEST_SPEC
-
APPIUM_RUBY_TEST_SPEC
-
APPIUM_WEB_JAVA_JUNIT_TEST_SPEC
-
APPIUM_WEB_JAVA_TESTNG_TEST_SPEC
-
APPIUM_WEB_PYTHON_TEST_SPEC
-
APPIUM_WEB_NODE_TEST_SPEC
-
APPIUM_WEB_RUBY_TEST_SPEC
-
INSTRUMENTATION_TEST_SPEC
-
XCTEST_UI_TEST_SPEC
If you call CreateUpload with WEB_APP specified, AWS Device Farm throws an ArgumentException error.
806 807 808 809 810 811 812 813 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 806 class CreateUploadRequest < Struct.new( :project_arn, :name, :type, :content_type) SENSITIVE = [] include Aws::Structure end |