Class: Aws::DeviceFarm::Types::Device

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Represents a device type that an app is tested against.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The device’s ARN.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#availabilityString

Indicates how likely a device is available for a test run. Currently available in the ListDevices and GetDevice API methods.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#carrierString

The device’s carrier.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#cpuTypes::CPU

Information about the device’s CPU.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_nameString

The name of the fleet to which this device belongs.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#fleet_typeString

The type of fleet to which this device belongs. Possible values are PRIVATE and PUBLIC.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#form_factorString

The device’s form factor.

Allowed values include:

  • PHONE

  • TABLET



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#heap_sizeInteger

The device’s heap size, expressed in bytes.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#imageString

The device’s image name.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#instancesArray<Types::DeviceInstance>

The instances that belong to this device.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#manufacturerString

The device’s manufacturer name.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#memoryInteger

The device’s total memory size, expressed in bytes.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#modelString

The device’s model name.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#model_idString

The device’s model ID.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The device’s display name.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#osString

The device’s operating system type.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The device’s platform.

Allowed values include:

  • ANDROID

  • IOS



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#radioString

The device’s radio.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#remote_access_enabledBoolean

Specifies whether remote access has been enabled for the specified device.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#remote_debug_enabledBoolean

This flag is set to true if remote debugging is enabled for the device.

Remote debugging is [no longer supported][1].

[1]: docs.aws.amazon.com/devicefarm/latest/developerguide/history.html



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end

#resolutionTypes::Resolution

The resolution of the device.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
# File 'lib/aws-sdk-devicefarm/types.rb', line 1165

class Device < Struct.new(
  :arn,
  :name,
  :manufacturer,
  :model,
  :model_id,
  :form_factor,
  :platform,
  :os,
  :cpu,
  :resolution,
  :heap_size,
  :memory,
  :image,
  :carrier,
  :radio,
  :remote_access_enabled,
  :remote_debug_enabled,
  :fleet_type,
  :fleet_name,
  :instances,
  :availability)
  SENSITIVE = []
  include Aws::Structure
end