Class: Aws::DeviceFarm::Types::ExecutionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ExecutionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents configuration information about a test run, such as the execution timeout (in minutes).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accounts_cleanup ⇒ Boolean
True if account cleanup is enabled at the beginning of the test.
-
#app_packages_cleanup ⇒ Boolean
True if app package cleanup is enabled at the beginning of the test.
-
#job_timeout_minutes ⇒ Integer
The number of minutes a test run executes before it times out.
-
#skip_app_resign ⇒ Boolean
When set to
true, for private devices, Device Farm does not sign your app again. -
#video_capture ⇒ Boolean
Set to true to enable video capture.
Instance Attribute Details
#accounts_cleanup ⇒ Boolean
True if account cleanup is enabled at the beginning of the test. Otherwise, false.
1669 1670 1671 1672 1673 1674 1675 1676 1677 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 1669 class ExecutionConfiguration < Struct.new( :job_timeout_minutes, :accounts_cleanup, :app_packages_cleanup, :video_capture, :skip_app_resign) SENSITIVE = [] include Aws::Structure end |
#app_packages_cleanup ⇒ Boolean
True if app package cleanup is enabled at the beginning of the test. Otherwise, false.
1669 1670 1671 1672 1673 1674 1675 1676 1677 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 1669 class ExecutionConfiguration < Struct.new( :job_timeout_minutes, :accounts_cleanup, :app_packages_cleanup, :video_capture, :skip_app_resign) SENSITIVE = [] include Aws::Structure end |
#job_timeout_minutes ⇒ Integer
The number of minutes a test run executes before it times out.
1669 1670 1671 1672 1673 1674 1675 1676 1677 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 1669 class ExecutionConfiguration < Struct.new( :job_timeout_minutes, :accounts_cleanup, :app_packages_cleanup, :video_capture, :skip_app_resign) SENSITIVE = [] include Aws::Structure end |
#skip_app_resign ⇒ Boolean
When set to true, for private devices, Device Farm does not sign your app again. For public devices, Device Farm always signs your apps again.
For more information about how Device Farm re-signs your apps, see
- Do you modify my app?][1
-
in the *AWS Device Farm FAQs*.
1669 1670 1671 1672 1673 1674 1675 1676 1677 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 1669 class ExecutionConfiguration < Struct.new( :job_timeout_minutes, :accounts_cleanup, :app_packages_cleanup, :video_capture, :skip_app_resign) SENSITIVE = [] include Aws::Structure end |
#video_capture ⇒ Boolean
Set to true to enable video capture. Otherwise, set to false. The default is true.
1669 1670 1671 1672 1673 1674 1675 1676 1677 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 1669 class ExecutionConfiguration < Struct.new( :job_timeout_minutes, :accounts_cleanup, :app_packages_cleanup, :video_capture, :skip_app_resign) SENSITIVE = [] include Aws::Structure end |