Class: Aws::DeviceFarm::Types::GetOfferingStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Represents the request to retrieve the offering status for the specified customer or account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.



1972
1973
1974
1975
1976
# File 'lib/aws-sdk-devicefarm/types.rb', line 1972

class GetOfferingStatusRequest < Struct.new(
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end