Class: Aws::DeviceFarm::Types::GetOfferingStatusResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Returns the status result for a device offering.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#currentHash<String,Types::OfferingStatus>

When specified, gets the offering status for the current period.



1996
1997
1998
1999
2000
2001
2002
# File 'lib/aws-sdk-devicefarm/types.rb', line 1996

class GetOfferingStatusResult < Struct.new(
  :current,
  :next_period,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_periodHash<String,Types::OfferingStatus>

When specified, gets the offering status for the next period.



1996
1997
1998
1999
2000
2001
2002
# File 'lib/aws-sdk-devicefarm/types.rb', line 1996

class GetOfferingStatusResult < Struct.new(
  :current,
  :next_period,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.



1996
1997
1998
1999
2000
2001
2002
# File 'lib/aws-sdk-devicefarm/types.rb', line 1996

class GetOfferingStatusResult < Struct.new(
  :current,
  :next_period,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end