Class: Aws::DeviceFarm::Types::Job

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Represents a device.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The job's ARN.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#countersTypes::Counters

The job's result counters.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#createdTime

When the job was created.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#deviceTypes::Device

The device (phone or tablet).

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#device_minutesTypes::DeviceMinutes

Represents the total (metered or unmetered) minutes used by the job.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#insightsTypes::JobInsights

The insights for the job, including the report status and test-level metrics. This field contains data only if you specified insightsTypes when you scheduled the run.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arnString

The ARN of the instance.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message about the job's result.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The job's name.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#resultString

The job's result.

Allowed values include:

  • PENDING

  • PASSED

  • WARNED

  • FAILED

  • SKIPPED

  • ERRORED

  • STOPPED

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#startedTime

The job's start time.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The job's status.

Allowed values include:

  • PENDING

  • PENDING_CONCURRENCY

  • PENDING_DEVICE

  • PROCESSING

  • SCHEDULING

  • PREPARING

  • RUNNING

  • COMPLETED

  • STOPPING

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#stoppedTime

The job's stop time.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The job's type.

Allowed values include the following:

  • BUILTIN_FUZZ

  • APPIUM_JAVA_JUNIT

  • APPIUM_JAVA_TESTNG

  • APPIUM_PYTHON

  • APPIUM_NODE

  • APPIUM_RUBY

  • APPIUM_WEB_JAVA_JUNIT

  • APPIUM_WEB_JAVA_TESTNG

  • APPIUM_WEB_PYTHON

  • APPIUM_WEB_NODE

  • APPIUM_WEB_RUBY

  • INSTRUMENTATION

  • XCTEST

  • XCTEST_UI

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#video_captureBoolean

This value is set to true if video capture is enabled. Otherwise, it is set to false.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end

#video_endpointString

The endpoint for streaming device video.

Returns:



2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
# File 'lib/aws-sdk-devicefarm/types.rb', line 2569

class Job < Struct.new(
  :arn,
  :name,
  :type,
  :created,
  :status,
  :result,
  :started,
  :stopped,
  :counters,
  :message,
  :device,
  :instance_arn,
  :device_minutes,
  :video_endpoint,
  :video_capture,
  :insights)
  SENSITIVE = []
  include Aws::Structure
end