Class: Aws::DeviceFarm::Types::JobInsights

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Contains insights for a job, including report status, and test-level aggregated metrics such as per test execution time and median test execution time.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#statusString

The status of the insights report for the job.

Returns:

  • (String)


2593
2594
2595
2596
2597
2598
# File 'lib/aws-sdk-devicefarm/types.rb', line 2593

class JobInsights < Struct.new(
  :status,
  :test_report)
  SENSITIVE = []
  include Aws::Structure
end

#test_reportTypes::TestReport

The test-level aggregated report for the job.

Returns:



2593
2594
2595
2596
2597
2598
# File 'lib/aws-sdk-devicefarm/types.rb', line 2593

class JobInsights < Struct.new(
  :status,
  :test_report)
  SENSITIVE = []
  include Aws::Structure
end