Class: Aws::DeviceFarm::Types::ListDeviceInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListDeviceInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An integer that specifies the maximum number of items you want to return in the API response.
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
Instance Attribute Details
#max_results ⇒ Integer
An integer that specifies the maximum number of items you want to return in the API response.
2777 2778 2779 2780 2781 2782 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 2777 class ListDeviceInstancesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
2777 2778 2779 2780 2781 2782 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 2777 class ListDeviceInstancesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |