Class: Aws::DeviceFarm::Types::ListDeviceInstancesResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListDeviceInstancesResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#device_instances ⇒ Array<Types::DeviceInstance>
An object that contains information about your device instances.
-
#next_token ⇒ String
An identifier that can be used in the next call to this operation to return the next set of items in the list.
Instance Attribute Details
#device_instances ⇒ Array<Types::DeviceInstance>
An object that contains information about your device instances.
2795 2796 2797 2798 2799 2800 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 2795 class ListDeviceInstancesResult < Struct.new( :device_instances, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that can be used in the next call to this operation to return the next set of items in the list.
2795 2796 2797 2798 2799 2800 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 2795 class ListDeviceInstancesResult < Struct.new( :device_instances, :next_token) SENSITIVE = [] include Aws::Structure end |