Class: Aws::DeviceFarm::Types::ListDevicePoolsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListDevicePoolsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents the result of a list device pools request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The project ARN.
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
-
#type ⇒ String
The device pools' type.
Instance Attribute Details
#arn ⇒ String
The project ARN.
2828 2829 2830 2831 2832 2833 2834 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 2828 class ListDevicePoolsRequest < Struct.new( :arn, :type, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
2828 2829 2830 2831 2832 2833 2834 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 2828 class ListDevicePoolsRequest < Struct.new( :arn, :type, :next_token) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The device pools' type.
Allowed values include:
-
CURATED: A device pool that is created and managed by AWS Device Farm.
-
PRIVATE: A device pool that is created and managed by the device pool developer.
2828 2829 2830 2831 2832 2833 2834 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 2828 class ListDevicePoolsRequest < Struct.new( :arn, :type, :next_token) SENSITIVE = [] include Aws::Structure end |