Class: Aws::DeviceFarm::Types::ListInstanceProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListInstanceProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An integer that specifies the maximum number of items you want to return in the API response.
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
Instance Attribute Details
#max_results ⇒ Integer
An integer that specifies the maximum number of items you want to return in the API response.
2986 2987 2988 2989 2990 2991 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 2986 class ListInstanceProfilesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
2986 2987 2988 2989 2990 2991 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 2986 class ListInstanceProfilesRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |