Class: Aws::DeviceFarm::Types::ListOfferingPromotionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListOfferingPromotionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
Instance Attribute Details
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
3107 3108 3109 3110 3111 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3107 class ListOfferingPromotionsRequest < Struct.new( :next_token) SENSITIVE = [] include Aws::Structure end |