Class: Aws::DeviceFarm::Types::ListOfferingTransactionsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListOfferingTransactionsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Returns the transaction log of the specified offerings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
-
#offering_transactions ⇒ Array<Types::OfferingTransaction>
The audit log of subscriptions you have purchased and modified through AWS Device Farm.
Instance Attribute Details
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
3162 3163 3164 3165 3166 3167 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3162 class ListOfferingTransactionsResult < Struct.new( :offering_transactions, :next_token) SENSITIVE = [] include Aws::Structure end |
#offering_transactions ⇒ Array<Types::OfferingTransaction>
The audit log of subscriptions you have purchased and modified through AWS Device Farm.
3162 3163 3164 3165 3166 3167 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3162 class ListOfferingTransactionsResult < Struct.new( :offering_transactions, :next_token) SENSITIVE = [] include Aws::Structure end |