Class: Aws::DeviceFarm::Types::ListOfferingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListOfferingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents the request to list all offerings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
Instance Attribute Details
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
3179 3180 3181 3182 3183 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3179 class ListOfferingsRequest < Struct.new( :next_token) SENSITIVE = [] include Aws::Structure end |