Class: Aws::DeviceFarm::Types::ListOfferingsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListOfferingsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents the return values of the list of offerings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
-
#offerings ⇒ Array<Types::Offering>
A value that represents the list offering results.
Instance Attribute Details
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
3199 3200 3201 3202 3203 3204 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3199 class ListOfferingsResult < Struct.new( :offerings, :next_token) SENSITIVE = [] include Aws::Structure end |
#offerings ⇒ Array<Types::Offering>
A value that represents the list offering results.
3199 3200 3201 3202 3203 3204 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3199 class ListOfferingsResult < Struct.new( :offerings, :next_token) SENSITIVE = [] include Aws::Structure end |