Class: Aws::DeviceFarm::Types::ListRemoteAccessSessionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Represents the request to return information about the remote access session.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the project about which you are requesting information.



3145
3146
3147
3148
3149
3150
# File 'lib/aws-sdk-devicefarm/types.rb', line 3145

class ListRemoteAccessSessionsRequest < Struct.new(
  :arn,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.



3145
3146
3147
3148
3149
3150
# File 'lib/aws-sdk-devicefarm/types.rb', line 3145

class ListRemoteAccessSessionsRequest < Struct.new(
  :arn,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end