Class: Aws::DeviceFarm::Types::ListRunsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListRunsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents a request to the list runs operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the project for which you want to list runs.
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the project for which you want to list runs.
3312 3313 3314 3315 3316 3317 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3312 class ListRunsRequest < Struct.new( :arn, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
3312 3313 3314 3315 3316 3317 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3312 class ListRunsRequest < Struct.new( :arn, :next_token) SENSITIVE = [] include Aws::Structure end |