Class: Aws::DeviceFarm::Types::ListSamplesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListSamplesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents a request to the list samples operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the job used to list samples.
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the job used to list samples.
3355 3356 3357 3358 3359 3360 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3355 class ListSamplesRequest < Struct.new( :arn, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
3355 3356 3357 3358 3359 3360 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3355 class ListSamplesRequest < Struct.new( :arn, :next_token) SENSITIVE = [] include Aws::Structure end |