Class: Aws::DeviceFarm::Types::ListSuitesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListSuitesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents a request to the list suites operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The job's Amazon Resource Name (ARN).
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
Instance Attribute Details
#arn ⇒ String
The job's Amazon Resource Name (ARN).
3398 3399 3400 3401 3402 3403 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3398 class ListSuitesRequest < Struct.new( :arn, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
3398 3399 3400 3401 3402 3403 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3398 class ListSuitesRequest < Struct.new( :arn, :next_token) SENSITIVE = [] include Aws::Structure end |