Class: Aws::DeviceFarm::Types::ListTestsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListTestsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents a request to the list tests operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The test suite's Amazon Resource Name (ARN).
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
Instance Attribute Details
#arn ⇒ String
The test suite's Amazon Resource Name (ARN).
3655 3656 3657 3658 3659 3660 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3655 class ListTestsRequest < Struct.new( :arn, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
3655 3656 3657 3658 3659 3660 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3655 class ListTestsRequest < Struct.new( :arn, :next_token) SENSITIVE = [] include Aws::Structure end |