Class: Aws::DeviceFarm::Types::ListUploadsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListUploadsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents a request to the list uploads operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the project for which you want to list uploads.
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
-
#type ⇒ String
The type of upload.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the project for which you want to list uploads.
3822 3823 3824 3825 3826 3827 3828 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3822 class ListUploadsRequest < Struct.new( :arn, :type, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
3822 3823 3824 3825 3826 3827 3828 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3822 class ListUploadsRequest < Struct.new( :arn, :type, :next_token) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of upload.
Must be one of the following values:
-
ANDROID_APP
-
IOS_APP
-
WEB_APP
-
EXTERNAL_DATA
-
APPIUM_JAVA_JUNIT_TEST_PACKAGE
-
APPIUM_JAVA_TESTNG_TEST_PACKAGE
-
APPIUM_PYTHON_TEST_PACKAGE
-
APPIUM_NODE_TEST_PACKAGE
-
APPIUM_RUBY_TEST_PACKAGE
-
APPIUM_WEB_JAVA_JUNIT_TEST_PACKAGE
-
APPIUM_WEB_JAVA_TESTNG_TEST_PACKAGE
-
APPIUM_WEB_PYTHON_TEST_PACKAGE
-
APPIUM_WEB_NODE_TEST_PACKAGE
-
APPIUM_WEB_RUBY_TEST_PACKAGE
-
INSTRUMENTATION_TEST_PACKAGE
-
XCTEST_TEST_PACKAGE
-
XCTEST_UI_TEST_PACKAGE
-
APPIUM_JAVA_JUNIT_TEST_SPEC
-
APPIUM_JAVA_TESTNG_TEST_SPEC
-
APPIUM_PYTHON_TEST_SPEC
-
APPIUM_NODE_TEST_SPEC
-
APPIUM_RUBY_TEST_SPEC
-
APPIUM_WEB_JAVA_JUNIT_TEST_SPEC
-
APPIUM_WEB_JAVA_TESTNG_TEST_SPEC
-
APPIUM_WEB_PYTHON_TEST_SPEC
-
APPIUM_WEB_NODE_TEST_SPEC
-
APPIUM_WEB_RUBY_TEST_SPEC
-
INSTRUMENTATION_TEST_SPEC
-
XCTEST_UI_TEST_SPEC
3822 3823 3824 3825 3826 3827 3828 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3822 class ListUploadsRequest < Struct.new( :arn, :type, :next_token) SENSITIVE = [] include Aws::Structure end |