Class: Aws::DeviceFarm::Types::ListVPCEConfigurationsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::ListVPCEConfigurationsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
-
#vpce_configurations ⇒ Array<Types::VPCEConfiguration>
An array of
VPCEConfigurationobjects that contain information about your VPC endpoint configuration.
Instance Attribute Details
#next_token ⇒ String
An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.
3885 3886 3887 3888 3889 3890 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3885 class ListVPCEConfigurationsResult < Struct.new( :vpce_configurations, :next_token) SENSITIVE = [] include Aws::Structure end |
#vpce_configurations ⇒ Array<Types::VPCEConfiguration>
An array of VPCEConfiguration objects that contain information
about your VPC endpoint configuration.
3885 3886 3887 3888 3889 3890 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 3885 class ListVPCEConfigurationsResult < Struct.new( :vpce_configurations, :next_token) SENSITIVE = [] include Aws::Structure end |