Class: Aws::DeviceFarm::Types::RemoteAccessSession

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Represents information about the remote access session.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#app_uploadString

The ARN for the app to be installed onto your device.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the remote access session.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#billing_methodString

The billing method of the remote access session. Possible values include METERED or UNMETERED. For more information about metered devices, see AWS Device Farm terminology.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#createdTime

The date and time the remote access session was created.

Returns:

  • (Time)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#deviceTypes::Device

The device (phone or tablet) used in the remote access session.

Returns:



4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#device_minutesTypes::DeviceMinutes

The number of minutes a device is used in a remote access session (including setup and teardown minutes).



4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#device_proxyTypes::DeviceProxy

The device proxy configured for the remote access session.

Returns:



4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#device_udidString

Unique device identifier for the remote device. Only returned if remote debugging is enabled for the remote access session.

Remote debugging is no longer supported.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#endpointString

The endpoint for the remote access session. This field is deprecated, and is replaced by the new endpoints.interactiveEndpoint field.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#endpointsTypes::RemoteAccessEndpoints

Represents the remote endpoints for viewing and controlling a device during a remote access session.



4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arnString

The ARN of the instance.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#interaction_modeString

The interaction mode of the remote access session. Changing the interactive mode of remote access sessions is no longer available.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message about the remote access session.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the remote access session.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#resultString

The result of the remote access session. Can be any of the following:

  • PENDING.

  • PASSED.

  • WARNED.

  • FAILED.

  • SKIPPED.

  • ERRORED.

  • STOPPED.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#skip_app_resignBoolean

When set to true, for private devices, Device Farm does not sign your app again. For public devices, Device Farm always signs your apps again.

For more information about how Device Farm re-signs your apps, see Do you modify my app? in the AWS Device Farm FAQs.

Returns:

  • (Boolean)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#startedTime

The date and time the remote access session was started.

Returns:

  • (Time)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the remote access session. Can be any of the following:

  • PENDING.

  • PENDING_CONCURRENCY.

  • PENDING_DEVICE.

  • PROCESSING.

  • SCHEDULING.

  • PREPARING.

  • RUNNING.

  • COMPLETED.

  • STOPPING.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#stoppedTime

The date and time the remote access session was stopped.

Returns:

  • (Time)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_configTypes::VpcConfig

The VPC security groups and subnets that are attached to a project.

Returns:



4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530

class RemoteAccessSession < Struct.new(
  :arn,
  :name,
  :created,
  :status,
  :result,
  :message,
  :started,
  :stopped,
  :device,
  :instance_arn,
  :billing_method,
  :device_minutes,
  :endpoint,
  :device_udid,
  :interaction_mode,
  :skip_app_resign,
  :vpc_config,
  :device_proxy,
  :app_upload,
  :endpoints)
  SENSITIVE = []
  include Aws::Structure
end