Class: Aws::DeviceFarm::Types::Run
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::Run
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents a test run on a set of devices with a given app package, test parameters, and so on.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_upload ⇒ String
An app to upload or that has been uploaded.
-
#arn ⇒ String
The run's ARN.
-
#billing_method ⇒ String
Specifies the billing method for a test run:
meteredorunmetered. -
#completed_jobs ⇒ Integer
The total number of completed jobs.
-
#counters ⇒ Types::Counters
The run's result counters.
-
#created ⇒ Time
When the run was created.
-
#customer_artifact_paths ⇒ Types::CustomerArtifactPaths
Output
CustomerArtifactPathsobject for the test run. -
#device_minutes ⇒ Types::DeviceMinutes
Represents the total (metered or unmetered) minutes used by the test run.
-
#device_pool_arn ⇒ String
The ARN of the device pool for the run.
-
#device_proxy ⇒ Types::DeviceProxy
The device proxy configured for the devices in the run.
-
#device_selection_result ⇒ Types::DeviceSelectionResult
The results of a device filter used to select the devices for a test run.
-
#environment_variables ⇒ Array<Types::EnvironmentVariable>
Environment variables associated with the run.
-
#event_count ⇒ Integer
For fuzz tests, this is the number of events, between 1 and 10000, that the UI fuzz test should perform.
-
#execution_role_arn ⇒ String
The IAM role associated with the run.
-
#insights ⇒ Types::RunInsights
The insights for the run, including the report status and job-level metrics.
-
#insights_types ⇒ Array<String>
The types of insights requested for the run.
-
#job_timeout_minutes ⇒ Integer
The number of minutes the job executes before it times out.
-
#locale ⇒ String
Information about the locale that is used for the run.
-
#location ⇒ Types::Location
Information about the location that is used for the run.
-
#message ⇒ String
A message about the run's result.
-
#name ⇒ String
The run's name.
-
#network_profile ⇒ Types::NetworkProfile
The network profile being used for a test run.
-
#parsing_result_url ⇒ String
Read-only URL for an object in an S3 bucket where you can get the parsing results of the test package.
-
#platform ⇒ String
The run's platform.
-
#radios ⇒ Types::Radios
Information about the radio states for the run.
-
#result ⇒ String
The run's result.
-
#result_code ⇒ String
Supporting field for the result field.
-
#seed ⇒ Integer
For fuzz tests, this is a seed to use for randomizing the UI fuzz test.
-
#skip_app_resign ⇒ Boolean
When set to
true, for private devices, Device Farm does not sign your app again. -
#started ⇒ Time
The run's start time.
-
#status ⇒ String
The run's status.
-
#stopped ⇒ Time
The run's stop time.
-
#test_spec_arn ⇒ String
The ARN of the YAML-formatted test specification for the run.
-
#total_jobs ⇒ Integer
The total number of jobs for the run.
-
#type ⇒ String
The run's type.
-
#vpc_config ⇒ Types::VpcConfig
The VPC security groups and subnets that are attached to a project.
-
#web_url ⇒ String
The Device Farm console URL for the recording of the run.
Instance Attribute Details
#app_upload ⇒ String
An app to upload or that has been uploaded.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The run's ARN.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#billing_method ⇒ String
Specifies the billing method for a test run: metered or
unmetered. If the parameter is not specified, the default value is
metered.
unmetered
to use them. Otherwise, the run is counted toward metered device
minutes.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#completed_jobs ⇒ Integer
The total number of completed jobs.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#counters ⇒ Types::Counters
The run's result counters.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#created ⇒ Time
When the run was created.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#customer_artifact_paths ⇒ Types::CustomerArtifactPaths
Output CustomerArtifactPaths object for the test run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#device_minutes ⇒ Types::DeviceMinutes
Represents the total (metered or unmetered) minutes used by the test run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#device_pool_arn ⇒ String
The ARN of the device pool for the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#device_proxy ⇒ Types::DeviceProxy
The device proxy configured for the devices in the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#device_selection_result ⇒ Types::DeviceSelectionResult
The results of a device filter used to select the devices for a test run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#environment_variables ⇒ Array<Types::EnvironmentVariable>
Environment variables associated with the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#event_count ⇒ Integer
For fuzz tests, this is the number of events, between 1 and 10000, that the UI fuzz test should perform.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#execution_role_arn ⇒ String
The IAM role associated with the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#insights ⇒ Types::RunInsights
The insights for the run, including the report status and job-level
metrics. This field contains data only if you specified
insightsTypes when you scheduled the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#insights_types ⇒ Array<String>
The types of insights requested for the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#job_timeout_minutes ⇒ Integer
The number of minutes the job executes before it times out.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#locale ⇒ String
Information about the locale that is used for the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#location ⇒ Types::Location
Information about the location that is used for the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message about the run's result.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The run's name.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#network_profile ⇒ Types::NetworkProfile
The network profile being used for a test run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#parsing_result_url ⇒ String
Read-only URL for an object in an S3 bucket where you can get the parsing results of the test package. If the test package doesn't parse, the reason why it doesn't parse appears in the file that this URL points to.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The run's platform.
Allowed values include:
-
ANDROID
-
IOS
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#radios ⇒ Types::Radios
Information about the radio states for the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#result ⇒ String
The run's result.
Allowed values include:
-
PENDING
-
PASSED
-
WARNED
-
FAILED
-
SKIPPED
-
ERRORED
-
STOPPED
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#result_code ⇒ String
Supporting field for the result field. Set only if result is
SKIPPED. PARSING_FAILED if the result is skipped because of test
package parsing failure.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#seed ⇒ Integer
For fuzz tests, this is a seed to use for randomizing the UI fuzz test. Using the same seed value between tests ensures identical event sequences.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#skip_app_resign ⇒ Boolean
When set to true, for private devices, Device Farm does not sign
your app again. For public devices, Device Farm always signs your
apps again.
For more information about how Device Farm re-signs your apps, see Do you modify my app? in the AWS Device Farm FAQs.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#started ⇒ Time
The run's start time.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The run's status.
Allowed values include:
-
PENDING
-
PENDING_CONCURRENCY
-
PENDING_DEVICE
-
PROCESSING
-
SCHEDULING
-
PREPARING
-
RUNNING
-
COMPLETED
-
STOPPING
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#stopped ⇒ Time
The run's stop time.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#test_spec_arn ⇒ String
The ARN of the YAML-formatted test specification for the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#total_jobs ⇒ Integer
The total number of jobs for the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The run's type.
Must be one of the following values:
-
BUILTIN_FUZZ
-
APPIUM_JAVA_JUNIT
-
APPIUM_JAVA_TESTNG
-
APPIUM_PYTHON
-
APPIUM_NODE
-
APPIUM_RUBY
-
APPIUM_WEB_JAVA_JUNIT
-
APPIUM_WEB_JAVA_TESTNG
-
APPIUM_WEB_PYTHON
-
APPIUM_WEB_NODE
-
APPIUM_WEB_RUBY
-
INSTRUMENTATION
-
XCTEST
-
XCTEST_UI
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The VPC security groups and subnets that are attached to a project.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |
#web_url ⇒ String
The Device Farm console URL for the recording of the run.
4983 4984 4985 4986 4987 4988 4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 4999 5000 5001 5002 5003 5004 5005 5006 5007 5008 5009 5010 5011 5012 5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4983 class Run < Struct.new( :arn, :name, :type, :platform, :created, :status, :result, :started, :stopped, :counters, :message, :total_jobs, :completed_jobs, :billing_method, :device_minutes, :network_profile, :device_proxy, :parsing_result_url, :result_code, :seed, :app_upload, :event_count, :job_timeout_minutes, :device_pool_arn, :locale, :radios, :location, :customer_artifact_paths, :web_url, :skip_app_resign, :test_spec_arn, :device_selection_result, :vpc_config, :execution_role_arn, :environment_variables, :insights_types, :insights) SENSITIVE = [] include Aws::Structure end |