Class: Aws::DeviceFarm::Types::ScheduleRunConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Represents the settings for a run. Includes things like location, radio states, auxiliary apps, and network profiles.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auxiliary_appsArray<String>

A list of upload ARNs for app packages to be installed with your app.

Returns:

  • (Array<String>)


5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#billing_methodString

Specifies the billing method for a test run: metered or unmetered. If the parameter is not specified, the default value is metered.

If you have purchased unmetered device slots, you must set this parameter to unmetered to make use of them. Otherwise, your run counts against your metered time.

Returns:

  • (String)


5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#customer_artifact_pathsTypes::CustomerArtifactPaths

Input CustomerArtifactPaths object for the scheduled run configuration.



5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#device_proxyTypes::DeviceProxy

The device proxy to be configured on the device for the run.

Returns:



5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#environment_variablesArray<Types::EnvironmentVariable>

Environment variables associated with the run.

Returns:



5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role_arnString

An IAM role to be assumed by the test host for the run.

Returns:

  • (String)


5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#extra_data_package_arnString

The ARN of the extra data for the run. The extra data is a .zip file that AWS Device Farm extracts to external data for Android or the app's sandbox for iOS.

Returns:

  • (String)


5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#insights_typesArray<String>

The types of insights to generate for a run. Specify one or more values to opt in to insights generation when scheduling a run.

Insights are currently supported for custom mode runs with Instrumentation, Appium Java TestNG, and XCTest UI test types.

Returns:

  • (Array<String>)


5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#localeString

Information about the locale that is used for the run.

Returns:

  • (String)


5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#locationTypes::Location

Information about the location that is used for the run.

Returns:



5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#network_profile_arnString

Reserved for internal use.

Returns:

  • (String)


5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#radiosTypes::Radios

Information about the radio states for the run.

Returns:



5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end

#vpce_configuration_arnsArray<String>

An array of ARNs for your VPC endpoint configurations.

Returns:

  • (Array<String>)


5186
5187
5188
5189
5190
5191
5192
5193
5194
5195
5196
5197
5198
5199
5200
5201
5202
# File 'lib/aws-sdk-devicefarm/types.rb', line 5186

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn,
  :insights_types)
  SENSITIVE = []
  include Aws::Structure
end