Method: Aws::DeviceFarm::Types::ScheduleRunConfiguration#billing_method

Defined in:
lib/aws-sdk-devicefarm/types.rb

#billing_methodString

Specifies the billing method for a test run: metered or unmetered. If the parameter is not specified, the default value is metered.

<note markdown=“1”> If you have purchased unmetered device slots, you must set this parameter to unmetered to make use of them. Otherwise, your run counts against your metered time.

</note>

Returns:

  • (String)


5034
5035
5036
5037
5038
5039
5040
5041
5042
5043
5044
5045
5046
5047
5048
5049
# File 'lib/aws-sdk-devicefarm/types.rb', line 5034

class ScheduleRunConfiguration < Struct.new(
  :extra_data_package_arn,
  :network_profile_arn,
  :locale,
  :location,
  :vpce_configuration_arns,
  :device_proxy,
  :customer_artifact_paths,
  :radios,
  :auxiliary_apps,
  :billing_method,
  :environment_variables,
  :execution_role_arn)
  SENSITIVE = []
  include Aws::Structure
end