Class: Aws::DeviceFarm::Types::TestGridSessionArtifact
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::TestGridSessionArtifact
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Artifacts are video and other files that are produced in the process of running a browser in an automated context.
Constant Summary collapse
- SENSITIVE =
[:url]
Instance Attribute Summary collapse
-
#filename ⇒ String
The file name of the artifact.
-
#type ⇒ String
The kind of artifact.
-
#url ⇒ String
A semi-stable URL to the content of the object.
Instance Attribute Details
#filename ⇒ String
The file name of the artifact.
5979 5980 5981 5982 5983 5984 5985 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 5979 class TestGridSessionArtifact < Struct.new( :filename, :type, :url) SENSITIVE = [:url] include Aws::Structure end |
#type ⇒ String
The kind of artifact.
5979 5980 5981 5982 5983 5984 5985 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 5979 class TestGridSessionArtifact < Struct.new( :filename, :type, :url) SENSITIVE = [:url] include Aws::Structure end |
#url ⇒ String
A semi-stable URL to the content of the object.
5979 5980 5981 5982 5983 5984 5985 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 5979 class TestGridSessionArtifact < Struct.new( :filename, :type, :url) SENSITIVE = [:url] include Aws::Structure end |