Class: Aws::DeviceFarm::Types::TestReportMetrics

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Contains aggregated metrics across all tests in a job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#median_test_execution_duration_secondsFloat

The median execution duration of tests in the job, in seconds.

Returns:

  • (Float)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075

class TestReportMetrics < Struct.new(
  :tests_total,
  :tests_passed,
  :tests_failed,
  :tests_skipped,
  :tests_errored,
  :tests_other,
  :tests_passed_percentage,
  :total_test_execution_duration_seconds,
  :median_test_execution_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#tests_erroredInteger

The number of tests that errored.

Returns:

  • (Integer)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075

class TestReportMetrics < Struct.new(
  :tests_total,
  :tests_passed,
  :tests_failed,
  :tests_skipped,
  :tests_errored,
  :tests_other,
  :tests_passed_percentage,
  :total_test_execution_duration_seconds,
  :median_test_execution_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#tests_failedInteger

The number of tests that failed.

Returns:

  • (Integer)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075

class TestReportMetrics < Struct.new(
  :tests_total,
  :tests_passed,
  :tests_failed,
  :tests_skipped,
  :tests_errored,
  :tests_other,
  :tests_passed_percentage,
  :total_test_execution_duration_seconds,
  :median_test_execution_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#tests_otherInteger

The number of tests with other result types.

Returns:

  • (Integer)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075

class TestReportMetrics < Struct.new(
  :tests_total,
  :tests_passed,
  :tests_failed,
  :tests_skipped,
  :tests_errored,
  :tests_other,
  :tests_passed_percentage,
  :total_test_execution_duration_seconds,
  :median_test_execution_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#tests_passedInteger

The number of tests that passed.

Returns:

  • (Integer)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075

class TestReportMetrics < Struct.new(
  :tests_total,
  :tests_passed,
  :tests_failed,
  :tests_skipped,
  :tests_errored,
  :tests_other,
  :tests_passed_percentage,
  :total_test_execution_duration_seconds,
  :median_test_execution_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#tests_passed_percentageFloat

The percentage of tests that passed.

Returns:

  • (Float)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075

class TestReportMetrics < Struct.new(
  :tests_total,
  :tests_passed,
  :tests_failed,
  :tests_skipped,
  :tests_errored,
  :tests_other,
  :tests_passed_percentage,
  :total_test_execution_duration_seconds,
  :median_test_execution_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#tests_skippedInteger

The number of tests that were skipped.

Returns:

  • (Integer)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075

class TestReportMetrics < Struct.new(
  :tests_total,
  :tests_passed,
  :tests_failed,
  :tests_skipped,
  :tests_errored,
  :tests_other,
  :tests_passed_percentage,
  :total_test_execution_duration_seconds,
  :median_test_execution_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#tests_totalInteger

The total number of tests in the job.

Returns:

  • (Integer)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075

class TestReportMetrics < Struct.new(
  :tests_total,
  :tests_passed,
  :tests_failed,
  :tests_skipped,
  :tests_errored,
  :tests_other,
  :tests_passed_percentage,
  :total_test_execution_duration_seconds,
  :median_test_execution_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#total_test_execution_duration_secondsFloat

The total execution duration of all tests in the job, in seconds.

Returns:

  • (Float)


6075
6076
6077
6078
6079
6080
6081
6082
6083
6084
6085
6086
6087
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075

class TestReportMetrics < Struct.new(
  :tests_total,
  :tests_passed,
  :tests_failed,
  :tests_skipped,
  :tests_errored,
  :tests_other,
  :tests_passed_percentage,
  :total_test_execution_duration_seconds,
  :median_test_execution_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end