Class: Aws::DeviceFarm::Types::UpdateNetworkProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::UpdateNetworkProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the project for which you want to update network profile settings.
-
#description ⇒ String
The description of the network profile about which you are returning information.
-
#downlink_bandwidth_bits ⇒ Integer
The data throughput rate in bits per second, as an integer from 0 to 104857600.
-
#downlink_delay_ms ⇒ Integer
Delay time for all packets to destination in milliseconds as an integer from 0 to 2000.
-
#downlink_jitter_ms ⇒ Integer
Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000.
-
#downlink_loss_percent ⇒ Integer
Proportion of received packets that fail to arrive from 0 to 100 percent.
-
#name ⇒ String
The name of the network profile about which you are returning information.
-
#type ⇒ String
The type of network profile to return information about.
-
#uplink_bandwidth_bits ⇒ Integer
The data throughput rate in bits per second, as an integer from 0 to 104857600.
-
#uplink_delay_ms ⇒ Integer
Delay time for all packets to destination in milliseconds as an integer from 0 to 2000.
-
#uplink_jitter_ms ⇒ Integer
Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000.
-
#uplink_loss_percent ⇒ Integer
Proportion of transmitted packets that fail to arrive from 0 to 100 percent.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the project for which you want to update network profile settings.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the network profile about which you are returning information.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |
#downlink_bandwidth_bits ⇒ Integer
The data throughput rate in bits per second, as an integer from 0 to 104857600.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |
#downlink_delay_ms ⇒ Integer
Delay time for all packets to destination in milliseconds as an integer from 0 to 2000.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |
#downlink_jitter_ms ⇒ Integer
Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |
#downlink_loss_percent ⇒ Integer
Proportion of received packets that fail to arrive from 0 to 100 percent.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the network profile about which you are returning information.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of network profile to return information about. Valid values are listed here.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |
#uplink_bandwidth_bits ⇒ Integer
The data throughput rate in bits per second, as an integer from 0 to 104857600.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |
#uplink_delay_ms ⇒ Integer
Delay time for all packets to destination in milliseconds as an integer from 0 to 2000.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |
#uplink_jitter_ms ⇒ Integer
Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |
#uplink_loss_percent ⇒ Integer
Proportion of transmitted packets that fail to arrive from 0 to 100 percent.
6399 6400 6401 6402 6403 6404 6405 6406 6407 6408 6409 6410 6411 6412 6413 6414 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6399 class UpdateNetworkProfileRequest < Struct.new( :arn, :name, :description, :type, :uplink_bandwidth_bits, :downlink_bandwidth_bits, :uplink_delay_ms, :downlink_delay_ms, :uplink_jitter_ms, :downlink_jitter_ms, :uplink_loss_percent, :downlink_loss_percent) SENSITIVE = [] include Aws::Structure end |