Class: Aws::DeviceFarm::Types::UpdateVPCEConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the VPC endpoint configuration you want to update.



6370
6371
6372
6373
6374
6375
6376
6377
6378
# File 'lib/aws-sdk-devicefarm/types.rb', line 6370

class UpdateVPCEConfigurationRequest < Struct.new(
  :arn,
  :vpce_configuration_name,
  :vpce_service_name,
  :service_dns_name,
  :vpce_configuration_description)
  SENSITIVE = []
  include Aws::Structure
end

#service_dns_nameString

The DNS (domain) name used to connect to your private service in your VPC. The DNS name must not already be in use on the internet.



6370
6371
6372
6373
6374
6375
6376
6377
6378
# File 'lib/aws-sdk-devicefarm/types.rb', line 6370

class UpdateVPCEConfigurationRequest < Struct.new(
  :arn,
  :vpce_configuration_name,
  :vpce_service_name,
  :service_dns_name,
  :vpce_configuration_description)
  SENSITIVE = []
  include Aws::Structure
end

#vpce_configuration_descriptionString

An optional description that provides details about your VPC endpoint configuration.



6370
6371
6372
6373
6374
6375
6376
6377
6378
# File 'lib/aws-sdk-devicefarm/types.rb', line 6370

class UpdateVPCEConfigurationRequest < Struct.new(
  :arn,
  :vpce_configuration_name,
  :vpce_service_name,
  :service_dns_name,
  :vpce_configuration_description)
  SENSITIVE = []
  include Aws::Structure
end

#vpce_configuration_nameString

The friendly name you give to your VPC endpoint configuration to manage your configurations more easily.



6370
6371
6372
6373
6374
6375
6376
6377
6378
# File 'lib/aws-sdk-devicefarm/types.rb', line 6370

class UpdateVPCEConfigurationRequest < Struct.new(
  :arn,
  :vpce_configuration_name,
  :vpce_service_name,
  :service_dns_name,
  :vpce_configuration_description)
  SENSITIVE = []
  include Aws::Structure
end

#vpce_service_nameString

The name of the VPC endpoint service running in your AWS account that you want Device Farm to test.



6370
6371
6372
6373
6374
6375
6376
6377
6378
# File 'lib/aws-sdk-devicefarm/types.rb', line 6370

class UpdateVPCEConfigurationRequest < Struct.new(
  :arn,
  :vpce_configuration_name,
  :vpce_service_name,
  :service_dns_name,
  :vpce_configuration_description)
  SENSITIVE = []
  include Aws::Structure
end