Method: Aws::DeviceFarm::Types::DeviceSelectionResult#max_devices
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
#max_devices ⇒ Integer
The maximum number of devices to be selected by a device filter and included in a test run.
1616 1617 1618 1619 1620 1621 1622 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 1616 class DeviceSelectionResult < Struct.new( :filters, :matched_devices_count, :max_devices) SENSITIVE = [] include Aws::Structure end |