Class: Aws::DeviceFarm::Types::JobInsights
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::JobInsights
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Contains insights for a job, including report status, and test-level aggregated metrics such as per test execution time and median test execution time.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The status of the insights report for the job.
-
#test_report ⇒ Types::TestReport
The test-level aggregated report for the job.
Instance Attribute Details
#status ⇒ String
The status of the insights report for the job.
2593 2594 2595 2596 2597 2598 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 2593 class JobInsights < Struct.new( :status, :test_report) SENSITIVE = [] include Aws::Structure end |
#test_report ⇒ Types::TestReport
The test-level aggregated report for the job.
2593 2594 2595 2596 2597 2598 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 2593 class JobInsights < Struct.new( :status, :test_report) SENSITIVE = [] include Aws::Structure end |