Class: Aws::DeviceFarm::Types::ListDevicePoolsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Represents the result of a list device pools request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The project ARN.



2706
2707
2708
2709
2710
2711
2712
# File 'lib/aws-sdk-devicefarm/types.rb', line 2706

class ListDevicePoolsRequest < Struct.new(
  :arn,
  :type,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.



2706
2707
2708
2709
2710
2711
2712
# File 'lib/aws-sdk-devicefarm/types.rb', line 2706

class ListDevicePoolsRequest < Struct.new(
  :arn,
  :type,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The device pools’ type.

Allowed values include:

  • CURATED: A device pool that is created and managed by AWS Device Farm.

  • PRIVATE: A device pool that is created and managed by the device pool developer.



2706
2707
2708
2709
2710
2711
2712
# File 'lib/aws-sdk-devicefarm/types.rb', line 2706

class ListDevicePoolsRequest < Struct.new(
  :arn,
  :type,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end