Class: Aws::DeviceFarm::Types::ListInstanceProfilesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

An integer that specifies the maximum number of items you want to return in the API response.



2864
2865
2866
2867
2868
2869
# File 'lib/aws-sdk-devicefarm/types.rb', line 2864

class ListInstanceProfilesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.



2864
2865
2866
2867
2868
2869
# File 'lib/aws-sdk-devicefarm/types.rb', line 2864

class ListInstanceProfilesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end