Class: Aws::DeviceFarm::Types::ListOfferingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Represents the request to list all offerings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.



3057
3058
3059
3060
3061
# File 'lib/aws-sdk-devicefarm/types.rb', line 3057

class ListOfferingsRequest < Struct.new(
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end