Class: Aws::DeviceFarm::Types::ListSuitesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Represents a request to the list suites operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The job’s Amazon Resource Name (ARN).



3276
3277
3278
3279
3280
3281
# File 'lib/aws-sdk-devicefarm/types.rb', line 3276

class ListSuitesRequest < Struct.new(
  :arn,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list.



3276
3277
3278
3279
3280
3281
# File 'lib/aws-sdk-devicefarm/types.rb', line 3276

class ListSuitesRequest < Struct.new(
  :arn,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end