Class: Aws::DeviceFarm::Types::RemoteAccessSession
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::RemoteAccessSession
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Represents information about the remote access session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_upload ⇒ String
The ARN for the app to be installed onto your device.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the remote access session.
-
#billing_method ⇒ String
The billing method of the remote access session.
-
#created ⇒ Time
The date and time the remote access session was created.
-
#device ⇒ Types::Device
The device (phone or tablet) used in the remote access session.
-
#device_minutes ⇒ Types::DeviceMinutes
The number of minutes a device is used in a remote access session (including setup and teardown minutes).
-
#device_proxy ⇒ Types::DeviceProxy
The device proxy configured for the remote access session.
-
#device_udid ⇒ String
Unique device identifier for the remote device.
-
#endpoint ⇒ String
The endpoint for the remote access session.
-
#endpoints ⇒ Types::RemoteAccessEndpoints
Represents the remote endpoints for viewing and controlling a device during a remote access session.
-
#instance_arn ⇒ String
The ARN of the instance.
-
#interaction_mode ⇒ String
The interaction mode of the remote access session.
-
#message ⇒ String
A message about the remote access session.
-
#name ⇒ String
The name of the remote access session.
-
#result ⇒ String
The result of the remote access session.
-
#skip_app_resign ⇒ Boolean
When set to
true, for private devices, Device Farm does not sign your app again. -
#started ⇒ Time
The date and time the remote access session was started.
-
#status ⇒ String
The status of the remote access session.
-
#stopped ⇒ Time
The date and time the remote access session was stopped.
-
#vpc_config ⇒ Types::VpcConfig
The VPC security groups and subnets that are attached to a project.
Instance Attribute Details
#app_upload ⇒ String
The ARN for the app to be installed onto your device.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the remote access session.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#billing_method ⇒ String
The billing method of the remote access session. Possible values
include METERED or UNMETERED. For more information about metered
devices, see AWS Device Farm terminology.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#created ⇒ Time
The date and time the remote access session was created.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#device ⇒ Types::Device
The device (phone or tablet) used in the remote access session.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#device_minutes ⇒ Types::DeviceMinutes
The number of minutes a device is used in a remote access session (including setup and teardown minutes).
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#device_proxy ⇒ Types::DeviceProxy
The device proxy configured for the remote access session.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#device_udid ⇒ String
Unique device identifier for the remote device. Only returned if remote debugging is enabled for the remote access session.
Remote debugging is no longer supported.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The endpoint for the remote access session. This field is
deprecated, and is replaced by the new
endpoints.interactiveEndpoint field.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#endpoints ⇒ Types::RemoteAccessEndpoints
Represents the remote endpoints for viewing and controlling a device during a remote access session.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the instance.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#interaction_mode ⇒ String
The interaction mode of the remote access session. Changing the interactive mode of remote access sessions is no longer available.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A message about the remote access session.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the remote access session.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#result ⇒ String
The result of the remote access session. Can be any of the following:
-
PENDING.
-
PASSED.
-
WARNED.
-
FAILED.
-
SKIPPED.
-
ERRORED.
-
STOPPED.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#skip_app_resign ⇒ Boolean
When set to true, for private devices, Device Farm does not sign
your app again. For public devices, Device Farm always signs your
apps again.
For more information about how Device Farm re-signs your apps, see Do you modify my app? in the AWS Device Farm FAQs.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#started ⇒ Time
The date and time the remote access session was started.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the remote access session. Can be any of the following:
-
PENDING.
-
PENDING_CONCURRENCY.
-
PENDING_DEVICE.
-
PROCESSING.
-
SCHEDULING.
-
PREPARING.
-
RUNNING.
-
COMPLETED.
-
STOPPING.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#stopped ⇒ Time
The date and time the remote access session was stopped.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |
#vpc_config ⇒ Types::VpcConfig
The VPC security groups and subnets that are attached to a project.
4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 4552 4553 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 4530 class RemoteAccessSession < Struct.new( :arn, :name, :created, :status, :result, :message, :started, :stopped, :device, :instance_arn, :billing_method, :device_minutes, :endpoint, :device_udid, :interaction_mode, :skip_app_resign, :vpc_config, :device_proxy, :app_upload, :endpoints) SENSITIVE = [] include Aws::Structure end |