Class: Aws::DeviceFarm::Types::RunInsights
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::RunInsights
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Contains insights for a run, including report status, and job-level aggregated metrics such as per job execution time and median job execution time.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#job_report ⇒ Types::JobReport
The job-level aggregated report for the run.
-
#status ⇒ String
The status of the insights report for the run.
Instance Attribute Details
#job_report ⇒ Types::JobReport
The job-level aggregated report for the run.
5039 5040 5041 5042 5043 5044 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 5039 class RunInsights < Struct.new( :status, :job_report) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the insights report for the run.
5039 5040 5041 5042 5043 5044 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 5039 class RunInsights < Struct.new( :status, :job_report) SENSITIVE = [] include Aws::Structure end |