Class: Aws::DeviceFarm::Types::TestReportMetrics
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::TestReportMetrics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Contains aggregated metrics across all tests in a job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#median_test_execution_duration_seconds ⇒ Float
The median execution duration of tests in the job, in seconds.
-
#tests_errored ⇒ Integer
The number of tests that errored.
-
#tests_failed ⇒ Integer
The number of tests that failed.
-
#tests_other ⇒ Integer
The number of tests with other result types.
-
#tests_passed ⇒ Integer
The number of tests that passed.
-
#tests_passed_percentage ⇒ Float
The percentage of tests that passed.
-
#tests_skipped ⇒ Integer
The number of tests that were skipped.
-
#tests_total ⇒ Integer
The total number of tests in the job.
-
#total_test_execution_duration_seconds ⇒ Float
The total execution duration of all tests in the job, in seconds.
Instance Attribute Details
#median_test_execution_duration_seconds ⇒ Float
The median execution duration of tests in the job, in seconds.
6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075 class TestReportMetrics < Struct.new( :tests_total, :tests_passed, :tests_failed, :tests_skipped, :tests_errored, :tests_other, :tests_passed_percentage, :total_test_execution_duration_seconds, :median_test_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#tests_errored ⇒ Integer
The number of tests that errored.
6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075 class TestReportMetrics < Struct.new( :tests_total, :tests_passed, :tests_failed, :tests_skipped, :tests_errored, :tests_other, :tests_passed_percentage, :total_test_execution_duration_seconds, :median_test_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#tests_failed ⇒ Integer
The number of tests that failed.
6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075 class TestReportMetrics < Struct.new( :tests_total, :tests_passed, :tests_failed, :tests_skipped, :tests_errored, :tests_other, :tests_passed_percentage, :total_test_execution_duration_seconds, :median_test_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#tests_other ⇒ Integer
The number of tests with other result types.
6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075 class TestReportMetrics < Struct.new( :tests_total, :tests_passed, :tests_failed, :tests_skipped, :tests_errored, :tests_other, :tests_passed_percentage, :total_test_execution_duration_seconds, :median_test_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#tests_passed ⇒ Integer
The number of tests that passed.
6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075 class TestReportMetrics < Struct.new( :tests_total, :tests_passed, :tests_failed, :tests_skipped, :tests_errored, :tests_other, :tests_passed_percentage, :total_test_execution_duration_seconds, :median_test_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#tests_passed_percentage ⇒ Float
The percentage of tests that passed.
6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075 class TestReportMetrics < Struct.new( :tests_total, :tests_passed, :tests_failed, :tests_skipped, :tests_errored, :tests_other, :tests_passed_percentage, :total_test_execution_duration_seconds, :median_test_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#tests_skipped ⇒ Integer
The number of tests that were skipped.
6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075 class TestReportMetrics < Struct.new( :tests_total, :tests_passed, :tests_failed, :tests_skipped, :tests_errored, :tests_other, :tests_passed_percentage, :total_test_execution_duration_seconds, :median_test_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#tests_total ⇒ Integer
The total number of tests in the job.
6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075 class TestReportMetrics < Struct.new( :tests_total, :tests_passed, :tests_failed, :tests_skipped, :tests_errored, :tests_other, :tests_passed_percentage, :total_test_execution_duration_seconds, :median_test_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |
#total_test_execution_duration_seconds ⇒ Float
The total execution duration of all tests in the job, in seconds.
6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 6087 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6075 class TestReportMetrics < Struct.new( :tests_total, :tests_passed, :tests_failed, :tests_skipped, :tests_errored, :tests_other, :tests_passed_percentage, :total_test_execution_duration_seconds, :median_test_execution_duration_seconds) SENSITIVE = [] include Aws::Structure end |