Class: Aws::DeviceFarm::Types::UpdateNetworkProfileRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devicefarm/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the project for which you want to update network profile settings.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the network profile about which you are returning information.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end

The data throughput rate in bits per second, as an integer from 0 to 104857600.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end

Delay time for all packets to destination in milliseconds as an integer from 0 to 2000.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end

Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end

Proportion of received packets that fail to arrive from 0 to 100 percent.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the network profile about which you are returning information.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of network profile to return information about. Valid values are listed here.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end

The data throughput rate in bits per second, as an integer from 0 to 104857600.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end

Delay time for all packets to destination in milliseconds as an integer from 0 to 2000.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end

Time variation in the delay of received packets in milliseconds as an integer from 0 to 2000.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end

Proportion of transmitted packets that fail to arrive from 0 to 100 percent.



6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
# File 'lib/aws-sdk-devicefarm/types.rb', line 6134

class UpdateNetworkProfileRequest < Struct.new(
  :arn,
  :name,
  :description,
  :type,
  :uplink_bandwidth_bits,
  :downlink_bandwidth_bits,
  :uplink_delay_ms,
  :downlink_delay_ms,
  :uplink_jitter_ms,
  :downlink_jitter_ms,
  :uplink_loss_percent,
  :downlink_loss_percent)
  SENSITIVE = []
  include Aws::Structure
end