Class: Aws::DeviceFarm::Types::UpdateVPCEConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::UpdateVPCEConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the VPC endpoint configuration you want to update.
-
#service_dns_name ⇒ String
The DNS (domain) name used to connect to your private service in your VPC.
-
#vpce_configuration_description ⇒ String
An optional description that provides details about your VPC endpoint configuration.
-
#vpce_configuration_name ⇒ String
The friendly name you give to your VPC endpoint configuration to manage your configurations more easily.
-
#vpce_service_name ⇒ String
The name of the VPC endpoint service running in your AWS account that you want Device Farm to test.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the VPC endpoint configuration you want to update.
6601 6602 6603 6604 6605 6606 6607 6608 6609 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6601 class UpdateVPCEConfigurationRequest < Struct.new( :arn, :vpce_configuration_name, :vpce_service_name, :service_dns_name, :vpce_configuration_description) SENSITIVE = [] include Aws::Structure end |
#service_dns_name ⇒ String
The DNS (domain) name used to connect to your private service in your VPC. The DNS name must not already be in use on the internet.
6601 6602 6603 6604 6605 6606 6607 6608 6609 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6601 class UpdateVPCEConfigurationRequest < Struct.new( :arn, :vpce_configuration_name, :vpce_service_name, :service_dns_name, :vpce_configuration_description) SENSITIVE = [] include Aws::Structure end |
#vpce_configuration_description ⇒ String
An optional description that provides details about your VPC endpoint configuration.
6601 6602 6603 6604 6605 6606 6607 6608 6609 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6601 class UpdateVPCEConfigurationRequest < Struct.new( :arn, :vpce_configuration_name, :vpce_service_name, :service_dns_name, :vpce_configuration_description) SENSITIVE = [] include Aws::Structure end |
#vpce_configuration_name ⇒ String
The friendly name you give to your VPC endpoint configuration to manage your configurations more easily.
6601 6602 6603 6604 6605 6606 6607 6608 6609 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6601 class UpdateVPCEConfigurationRequest < Struct.new( :arn, :vpce_configuration_name, :vpce_service_name, :service_dns_name, :vpce_configuration_description) SENSITIVE = [] include Aws::Structure end |
#vpce_service_name ⇒ String
The name of the VPC endpoint service running in your AWS account that you want Device Farm to test.
6601 6602 6603 6604 6605 6606 6607 6608 6609 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6601 class UpdateVPCEConfigurationRequest < Struct.new( :arn, :vpce_configuration_name, :vpce_service_name, :service_dns_name, :vpce_configuration_description) SENSITIVE = [] include Aws::Structure end |