Class: Aws::DeviceFarm::Types::Upload
- Inherits:
-
Struct
- Object
- Struct
- Aws::DeviceFarm::Types::Upload
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-devicefarm/types.rb
Overview
An app or a set of one or more tests to upload or that have been uploaded.
Constant Summary collapse
- SENSITIVE =
[:url]
Instance Attribute Summary collapse
-
#arn ⇒ String
The upload's ARN.
-
#category ⇒ String
The upload's category.
-
#content_type ⇒ String
The upload's content type (for example,
application/octet-stream). -
#created ⇒ Time
When the upload was created.
-
#message ⇒ String
A message about the upload's result.
-
#metadata ⇒ String
The upload's metadata.
-
#name ⇒ String
The upload's file name.
-
#status ⇒ String
The upload's status.
-
#type ⇒ String
The upload's type.
-
#url ⇒ String
The presigned Amazon S3 URL that was used to store a file using a PUT request.
Instance Attribute Details
#arn ⇒ String
The upload's ARN.
6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6747 class Upload < Struct.new( :arn, :name, :created, :type, :status, :url, :metadata, :content_type, :message, :category) SENSITIVE = [:url] include Aws::Structure end |
#category ⇒ String
The upload's category. Allowed values include:
-
CURATED: An upload managed by AWS Device Farm.
-
PRIVATE: An upload managed by the AWS Device Farm customer.
6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6747 class Upload < Struct.new( :arn, :name, :created, :type, :status, :url, :metadata, :content_type, :message, :category) SENSITIVE = [:url] include Aws::Structure end |
#content_type ⇒ String
The upload's content type (for example,
application/octet-stream).
6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6747 class Upload < Struct.new( :arn, :name, :created, :type, :status, :url, :metadata, :content_type, :message, :category) SENSITIVE = [:url] include Aws::Structure end |
#created ⇒ Time
When the upload was created.
6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6747 class Upload < Struct.new( :arn, :name, :created, :type, :status, :url, :metadata, :content_type, :message, :category) SENSITIVE = [:url] include Aws::Structure end |
#message ⇒ String
A message about the upload's result.
6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6747 class Upload < Struct.new( :arn, :name, :created, :type, :status, :url, :metadata, :content_type, :message, :category) SENSITIVE = [:url] include Aws::Structure end |
#metadata ⇒ String
The upload's metadata. For example, for Android, this contains information that is parsed from the manifest and is displayed in the AWS Device Farm console after the associated app is uploaded.
6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6747 class Upload < Struct.new( :arn, :name, :created, :type, :status, :url, :metadata, :content_type, :message, :category) SENSITIVE = [:url] include Aws::Structure end |
#name ⇒ String
The upload's file name.
6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6747 class Upload < Struct.new( :arn, :name, :created, :type, :status, :url, :metadata, :content_type, :message, :category) SENSITIVE = [:url] include Aws::Structure end |
#status ⇒ String
The upload's status.
Must be one of the following values:
-
FAILED
-
INITIALIZED
-
PROCESSING
-
SUCCEEDED
6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6747 class Upload < Struct.new( :arn, :name, :created, :type, :status, :url, :metadata, :content_type, :message, :category) SENSITIVE = [:url] include Aws::Structure end |
#type ⇒ String
The upload's type.
Must be one of the following values:
-
ANDROID_APP
-
IOS_APP
-
WEB_APP
-
EXTERNAL_DATA
-
APPIUM_JAVA_JUNIT_TEST_PACKAGE
-
APPIUM_JAVA_TESTNG_TEST_PACKAGE
-
APPIUM_PYTHON_TEST_PACKAGE
-
APPIUM_NODE_TEST_PACKAGE
-
APPIUM_RUBY_TEST_PACKAGE
-
APPIUM_WEB_JAVA_JUNIT_TEST_PACKAGE
-
APPIUM_WEB_JAVA_TESTNG_TEST_PACKAGE
-
APPIUM_WEB_PYTHON_TEST_PACKAGE
-
APPIUM_WEB_NODE_TEST_PACKAGE
-
APPIUM_WEB_RUBY_TEST_PACKAGE
-
INSTRUMENTATION_TEST_PACKAGE
-
XCTEST_TEST_PACKAGE
-
XCTEST_UI_TEST_PACKAGE
-
APPIUM_JAVA_JUNIT_TEST_SPEC
-
APPIUM_JAVA_TESTNG_TEST_SPEC
-
APPIUM_PYTHON_TEST_SPEC
-
APPIUM_NODE_TEST_SPEC
-
APPIUM_RUBY_TEST_SPEC
-
APPIUM_WEB_JAVA_JUNIT_TEST_SPEC
-
APPIUM_WEB_JAVA_TESTNG_TEST_SPEC
-
APPIUM_WEB_PYTHON_TEST_SPEC
-
APPIUM_WEB_NODE_TEST_SPEC
-
APPIUM_WEB_RUBY_TEST_SPEC
-
INSTRUMENTATION_TEST_SPEC
-
XCTEST_UI_TEST_SPEC
6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6747 class Upload < Struct.new( :arn, :name, :created, :type, :status, :url, :metadata, :content_type, :message, :category) SENSITIVE = [:url] include Aws::Structure end |
#url ⇒ String
The presigned Amazon S3 URL that was used to store a file using a PUT request.
6747 6748 6749 6750 6751 6752 6753 6754 6755 6756 6757 6758 6759 6760 |
# File 'lib/aws-sdk-devicefarm/types.rb', line 6747 class Upload < Struct.new( :arn, :name, :created, :type, :status, :url, :metadata, :content_type, :message, :category) SENSITIVE = [:url] include Aws::Structure end |